org

package
v0.0.0-...-00cfc7d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the org type in the database.
	Label = "org"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldOwnerID holds the string denoting the owner_id field in the database.
	FieldOwnerID = "owner_id"
	// FieldKind holds the string denoting the kind field in the database.
	FieldKind = "kind"
	// FieldParentID holds the string denoting the parent_id field in the database.
	FieldParentID = "parent_id"
	// FieldPath holds the string denoting the path field in the database.
	FieldPath = "path"
	// EdgeMsgAlerts holds the string denoting the msg_alerts edge name in mutations.
	EdgeMsgAlerts = "msg_alerts"
	// Table holds the table name of the org in the database.
	Table = "org"
	// MsgAlertsTable is the table that holds the msg_alerts relation/edge.
	MsgAlertsTable = "msg_alert"
	// MsgAlertsInverseTable is the table name for the MsgAlert entity.
	// It exists in this package in order to avoid circular dependency with the "msgalert" package.
	MsgAlertsInverseTable = "msg_alert"
	// MsgAlertsColumn is the table column denoting the msg_alerts relation/edge.
	MsgAlertsColumn = "tenant_id"
)

Variables

Columns holds all SQL columns for org fields.

var (
	Hooks [1]ent.Hook
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/woocoos/msgcenter/ent/runtime"

Functions

func And

func And(predicates ...predicate.Org) predicate.Org

And groups predicates with the AND operator between them.

func HasMsgAlerts

func HasMsgAlerts() predicate.Org

HasMsgAlerts applies the HasEdge predicate on the "msg_alerts" edge.

func HasMsgAlertsWith

func HasMsgAlertsWith(preds ...predicate.MsgAlert) predicate.Org

HasMsgAlertsWith applies the HasEdge predicate on the "msg_alerts" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Org

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Org

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Org

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Org

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Org

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Org

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Org

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Org

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Org

IDNotIn applies the NotIn predicate on the ID field.

func Kind

func Kind(v string) predicate.Org

Kind applies equality check predicate on the "kind" field. It's identical to KindEQ.

func KindContains

func KindContains(v string) predicate.Org

KindContains applies the Contains predicate on the "kind" field.

func KindContainsFold

func KindContainsFold(v string) predicate.Org

KindContainsFold applies the ContainsFold predicate on the "kind" field.

func KindEQ

func KindEQ(v string) predicate.Org

KindEQ applies the EQ predicate on the "kind" field.

func KindEqualFold

func KindEqualFold(v string) predicate.Org

KindEqualFold applies the EqualFold predicate on the "kind" field.

func KindGT

func KindGT(v string) predicate.Org

KindGT applies the GT predicate on the "kind" field.

func KindGTE

func KindGTE(v string) predicate.Org

KindGTE applies the GTE predicate on the "kind" field.

func KindHasPrefix

func KindHasPrefix(v string) predicate.Org

KindHasPrefix applies the HasPrefix predicate on the "kind" field.

func KindHasSuffix

func KindHasSuffix(v string) predicate.Org

KindHasSuffix applies the HasSuffix predicate on the "kind" field.

func KindIn

func KindIn(vs ...string) predicate.Org

KindIn applies the In predicate on the "kind" field.

func KindIsNil

func KindIsNil() predicate.Org

KindIsNil applies the IsNil predicate on the "kind" field.

func KindLT

func KindLT(v string) predicate.Org

KindLT applies the LT predicate on the "kind" field.

func KindLTE

func KindLTE(v string) predicate.Org

KindLTE applies the LTE predicate on the "kind" field.

func KindNEQ

func KindNEQ(v string) predicate.Org

KindNEQ applies the NEQ predicate on the "kind" field.

func KindNotIn

func KindNotIn(vs ...string) predicate.Org

KindNotIn applies the NotIn predicate on the "kind" field.

func KindNotNil

func KindNotNil() predicate.Org

KindNotNil applies the NotNil predicate on the "kind" field.

func Not

func Not(p predicate.Org) predicate.Org

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Org) predicate.Org

Or groups predicates with the OR operator between them.

func OwnerID

func OwnerID(v int) predicate.Org

OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.

func OwnerIDEQ

func OwnerIDEQ(v int) predicate.Org

OwnerIDEQ applies the EQ predicate on the "owner_id" field.

func OwnerIDGT

func OwnerIDGT(v int) predicate.Org

OwnerIDGT applies the GT predicate on the "owner_id" field.

func OwnerIDGTE

func OwnerIDGTE(v int) predicate.Org

OwnerIDGTE applies the GTE predicate on the "owner_id" field.

func OwnerIDIn

func OwnerIDIn(vs ...int) predicate.Org

OwnerIDIn applies the In predicate on the "owner_id" field.

func OwnerIDIsNil

func OwnerIDIsNil() predicate.Org

OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.

func OwnerIDLT

func OwnerIDLT(v int) predicate.Org

OwnerIDLT applies the LT predicate on the "owner_id" field.

func OwnerIDLTE

func OwnerIDLTE(v int) predicate.Org

OwnerIDLTE applies the LTE predicate on the "owner_id" field.

func OwnerIDNEQ

func OwnerIDNEQ(v int) predicate.Org

OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.

func OwnerIDNotIn

func OwnerIDNotIn(vs ...int) predicate.Org

OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.

func OwnerIDNotNil

func OwnerIDNotNil() predicate.Org

OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.

func ParentID

func ParentID(v int) predicate.Org

ParentID applies equality check predicate on the "parent_id" field. It's identical to ParentIDEQ.

func ParentIDEQ

func ParentIDEQ(v int) predicate.Org

ParentIDEQ applies the EQ predicate on the "parent_id" field.

func ParentIDGT

func ParentIDGT(v int) predicate.Org

ParentIDGT applies the GT predicate on the "parent_id" field.

func ParentIDGTE

func ParentIDGTE(v int) predicate.Org

ParentIDGTE applies the GTE predicate on the "parent_id" field.

func ParentIDIn

func ParentIDIn(vs ...int) predicate.Org

ParentIDIn applies the In predicate on the "parent_id" field.

func ParentIDIsNil

func ParentIDIsNil() predicate.Org

ParentIDIsNil applies the IsNil predicate on the "parent_id" field.

func ParentIDLT

func ParentIDLT(v int) predicate.Org

ParentIDLT applies the LT predicate on the "parent_id" field.

func ParentIDLTE

func ParentIDLTE(v int) predicate.Org

ParentIDLTE applies the LTE predicate on the "parent_id" field.

func ParentIDNEQ

func ParentIDNEQ(v int) predicate.Org

ParentIDNEQ applies the NEQ predicate on the "parent_id" field.

func ParentIDNotIn

func ParentIDNotIn(vs ...int) predicate.Org

ParentIDNotIn applies the NotIn predicate on the "parent_id" field.

func ParentIDNotNil

func ParentIDNotNil() predicate.Org

ParentIDNotNil applies the NotNil predicate on the "parent_id" field.

func Path

func Path(v string) predicate.Org

Path applies equality check predicate on the "path" field. It's identical to PathEQ.

func PathContains

func PathContains(v string) predicate.Org

PathContains applies the Contains predicate on the "path" field.

func PathContainsFold

func PathContainsFold(v string) predicate.Org

PathContainsFold applies the ContainsFold predicate on the "path" field.

func PathEQ

func PathEQ(v string) predicate.Org

PathEQ applies the EQ predicate on the "path" field.

func PathEqualFold

func PathEqualFold(v string) predicate.Org

PathEqualFold applies the EqualFold predicate on the "path" field.

func PathGT

func PathGT(v string) predicate.Org

PathGT applies the GT predicate on the "path" field.

func PathGTE

func PathGTE(v string) predicate.Org

PathGTE applies the GTE predicate on the "path" field.

func PathHasPrefix

func PathHasPrefix(v string) predicate.Org

PathHasPrefix applies the HasPrefix predicate on the "path" field.

func PathHasSuffix

func PathHasSuffix(v string) predicate.Org

PathHasSuffix applies the HasSuffix predicate on the "path" field.

func PathIn

func PathIn(vs ...string) predicate.Org

PathIn applies the In predicate on the "path" field.

func PathIsNil

func PathIsNil() predicate.Org

PathIsNil applies the IsNil predicate on the "path" field.

func PathLT

func PathLT(v string) predicate.Org

PathLT applies the LT predicate on the "path" field.

func PathLTE

func PathLTE(v string) predicate.Org

PathLTE applies the LTE predicate on the "path" field.

func PathNEQ

func PathNEQ(v string) predicate.Org

PathNEQ applies the NEQ predicate on the "path" field.

func PathNotIn

func PathNotIn(vs ...string) predicate.Org

PathNotIn applies the NotIn predicate on the "path" field.

func PathNotNil

func PathNotNil() predicate.Org

PathNotNil applies the NotNil predicate on the "path" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Org queries.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByKind

func ByKind(opts ...sql.OrderTermOption) OrderOption

ByKind orders the results by the kind field.

func ByMsgAlerts

func ByMsgAlerts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByMsgAlerts orders the results by msg_alerts terms.

func ByMsgAlertsCount

func ByMsgAlertsCount(opts ...sql.OrderTermOption) OrderOption

ByMsgAlertsCount orders the results by msg_alerts count.

func ByOwnerID

func ByOwnerID(opts ...sql.OrderTermOption) OrderOption

ByOwnerID orders the results by the owner_id field.

func ByParentID

func ByParentID(opts ...sql.OrderTermOption) OrderOption

ByParentID orders the results by the parent_id field.

func ByPath

func ByPath(opts ...sql.OrderTermOption) OrderOption

ByPath orders the results by the path field.

Jump to