Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Org) predicate.Org
- func HasMsgAlerts() predicate.Org
- func HasMsgAlertsWith(preds ...predicate.MsgAlert) predicate.Org
- func ID(id int) predicate.Org
- func IDEQ(id int) predicate.Org
- func IDGT(id int) predicate.Org
- func IDGTE(id int) predicate.Org
- func IDIn(ids ...int) predicate.Org
- func IDLT(id int) predicate.Org
- func IDLTE(id int) predicate.Org
- func IDNEQ(id int) predicate.Org
- func IDNotIn(ids ...int) predicate.Org
- func Kind(v string) predicate.Org
- func KindContains(v string) predicate.Org
- func KindContainsFold(v string) predicate.Org
- func KindEQ(v string) predicate.Org
- func KindEqualFold(v string) predicate.Org
- func KindGT(v string) predicate.Org
- func KindGTE(v string) predicate.Org
- func KindHasPrefix(v string) predicate.Org
- func KindHasSuffix(v string) predicate.Org
- func KindIn(vs ...string) predicate.Org
- func KindIsNil() predicate.Org
- func KindLT(v string) predicate.Org
- func KindLTE(v string) predicate.Org
- func KindNEQ(v string) predicate.Org
- func KindNotIn(vs ...string) predicate.Org
- func KindNotNil() predicate.Org
- func Not(p predicate.Org) predicate.Org
- func Or(predicates ...predicate.Org) predicate.Org
- func OwnerID(v int) predicate.Org
- func OwnerIDEQ(v int) predicate.Org
- func OwnerIDGT(v int) predicate.Org
- func OwnerIDGTE(v int) predicate.Org
- func OwnerIDIn(vs ...int) predicate.Org
- func OwnerIDIsNil() predicate.Org
- func OwnerIDLT(v int) predicate.Org
- func OwnerIDLTE(v int) predicate.Org
- func OwnerIDNEQ(v int) predicate.Org
- func OwnerIDNotIn(vs ...int) predicate.Org
- func OwnerIDNotNil() predicate.Org
- func ParentID(v int) predicate.Org
- func ParentIDEQ(v int) predicate.Org
- func ParentIDGT(v int) predicate.Org
- func ParentIDGTE(v int) predicate.Org
- func ParentIDIn(vs ...int) predicate.Org
- func ParentIDIsNil() predicate.Org
- func ParentIDLT(v int) predicate.Org
- func ParentIDLTE(v int) predicate.Org
- func ParentIDNEQ(v int) predicate.Org
- func ParentIDNotIn(vs ...int) predicate.Org
- func ParentIDNotNil() predicate.Org
- func Path(v string) predicate.Org
- func PathContains(v string) predicate.Org
- func PathContainsFold(v string) predicate.Org
- func PathEQ(v string) predicate.Org
- func PathEqualFold(v string) predicate.Org
- func PathGT(v string) predicate.Org
- func PathGTE(v string) predicate.Org
- func PathHasPrefix(v string) predicate.Org
- func PathHasSuffix(v string) predicate.Org
- func PathIn(vs ...string) predicate.Org
- func PathIsNil() predicate.Org
- func PathLT(v string) predicate.Org
- func PathLTE(v string) predicate.Org
- func PathNEQ(v string) predicate.Org
- func PathNotIn(vs ...string) predicate.Org
- func PathNotNil() predicate.Org
- func ValidColumn(column string) bool
- type OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByKind(opts ...sql.OrderTermOption) OrderOption
- func ByMsgAlerts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMsgAlertsCount(opts ...sql.OrderTermOption) OrderOption
- func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
- func ByParentID(opts ...sql.OrderTermOption) OrderOption
- func ByPath(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the org type in the database. Label = "org" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldOwnerID holds the string denoting the owner_id field in the database. FieldOwnerID = "owner_id" // FieldKind holds the string denoting the kind field in the database. FieldKind = "kind" // FieldParentID holds the string denoting the parent_id field in the database. FieldParentID = "parent_id" // FieldPath holds the string denoting the path field in the database. FieldPath = "path" // EdgeMsgAlerts holds the string denoting the msg_alerts edge name in mutations. EdgeMsgAlerts = "msg_alerts" // Table holds the table name of the org in the database. Table = "org" // MsgAlertsTable is the table that holds the msg_alerts relation/edge. MsgAlertsTable = "msg_alert" // MsgAlertsInverseTable is the table name for the MsgAlert entity. // It exists in this package in order to avoid circular dependency with the "msgalert" package. MsgAlertsInverseTable = "msg_alert" // MsgAlertsColumn is the table column denoting the msg_alerts relation/edge. MsgAlertsColumn = "tenant_id" )
Variables ¶
var Columns = []string{ FieldID, FieldOwnerID, FieldKind, FieldParentID, FieldPath, }
Columns holds all SQL columns for org fields.
var (
Hooks [1]ent.Hook
)
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/woocoos/msgcenter/ent/runtime"
Functions ¶
func HasMsgAlerts ¶
HasMsgAlerts applies the HasEdge predicate on the "msg_alerts" edge.
func HasMsgAlertsWith ¶
HasMsgAlertsWith applies the HasEdge predicate on the "msg_alerts" edge with a given conditions (other predicates).
func KindContains ¶
KindContains applies the Contains predicate on the "kind" field.
func KindContainsFold ¶
KindContainsFold applies the ContainsFold predicate on the "kind" field.
func KindEqualFold ¶
KindEqualFold applies the EqualFold predicate on the "kind" field.
func KindHasPrefix ¶
KindHasPrefix applies the HasPrefix predicate on the "kind" field.
func KindHasSuffix ¶
KindHasSuffix applies the HasSuffix predicate on the "kind" field.
func KindNotNil ¶
KindNotNil applies the NotNil predicate on the "kind" field.
func OwnerID ¶
OwnerID applies equality check predicate on the "owner_id" field. It's identical to OwnerIDEQ.
func OwnerIDGTE ¶
OwnerIDGTE applies the GTE predicate on the "owner_id" field.
func OwnerIDIsNil ¶
OwnerIDIsNil applies the IsNil predicate on the "owner_id" field.
func OwnerIDLTE ¶
OwnerIDLTE applies the LTE predicate on the "owner_id" field.
func OwnerIDNEQ ¶
OwnerIDNEQ applies the NEQ predicate on the "owner_id" field.
func OwnerIDNotIn ¶
OwnerIDNotIn applies the NotIn predicate on the "owner_id" field.
func OwnerIDNotNil ¶
OwnerIDNotNil applies the NotNil predicate on the "owner_id" field.
func ParentID ¶
ParentID applies equality check predicate on the "parent_id" field. It's identical to ParentIDEQ.
func ParentIDEQ ¶
ParentIDEQ applies the EQ predicate on the "parent_id" field.
func ParentIDGT ¶
ParentIDGT applies the GT predicate on the "parent_id" field.
func ParentIDGTE ¶
ParentIDGTE applies the GTE predicate on the "parent_id" field.
func ParentIDIn ¶
ParentIDIn applies the In predicate on the "parent_id" field.
func ParentIDIsNil ¶
ParentIDIsNil applies the IsNil predicate on the "parent_id" field.
func ParentIDLT ¶
ParentIDLT applies the LT predicate on the "parent_id" field.
func ParentIDLTE ¶
ParentIDLTE applies the LTE predicate on the "parent_id" field.
func ParentIDNEQ ¶
ParentIDNEQ applies the NEQ predicate on the "parent_id" field.
func ParentIDNotIn ¶
ParentIDNotIn applies the NotIn predicate on the "parent_id" field.
func ParentIDNotNil ¶
ParentIDNotNil applies the NotNil predicate on the "parent_id" field.
func PathContains ¶
PathContains applies the Contains predicate on the "path" field.
func PathContainsFold ¶
PathContainsFold applies the ContainsFold predicate on the "path" field.
func PathEqualFold ¶
PathEqualFold applies the EqualFold predicate on the "path" field.
func PathHasPrefix ¶
PathHasPrefix applies the HasPrefix predicate on the "path" field.
func PathHasSuffix ¶
PathHasSuffix applies the HasSuffix predicate on the "path" field.
func PathNotNil ¶
PathNotNil applies the NotNil predicate on the "path" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Org queries.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByKind ¶
func ByKind(opts ...sql.OrderTermOption) OrderOption
ByKind orders the results by the kind field.
func ByMsgAlerts ¶
func ByMsgAlerts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMsgAlerts orders the results by msg_alerts terms.
func ByMsgAlertsCount ¶
func ByMsgAlertsCount(opts ...sql.OrderTermOption) OrderOption
ByMsgAlertsCount orders the results by msg_alerts count.
func ByOwnerID ¶
func ByOwnerID(opts ...sql.OrderTermOption) OrderOption
ByOwnerID orders the results by the owner_id field.
func ByParentID ¶
func ByParentID(opts ...sql.OrderTermOption) OrderOption
ByParentID orders the results by the parent_id field.
func ByPath ¶
func ByPath(opts ...sql.OrderTermOption) OrderOption
ByPath orders the results by the path field.